CustomAlertImage class
Constructors
- CustomAlertImage({ImageSrc? src, Color? color, double borderRadius = 0, Alignment alignment = Alignment.center, Size imageSize = const Size(100, 100), EdgeInsetsGeometry imageMargin = const EdgeInsets.only(top: 20)})
-
const
Properties
- alignment → Alignment
-
final
- borderRadius → double
-
final
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageMargin → EdgeInsetsGeometry
-
final
- imageSize → Size
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → ImageSrc?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited