ImageSrc class

Constructors

ImageSrc({String? assetPath, String? filePath, String? url, String? package})
const

Properties

assetPath String?
final
filePath String?
final
hashCode int
The hash code for this object.
no setterinherited
package String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

confirm ImageSrc
no setter
delete ImageSrc
no setter
donot ImageSrc
no setter
error ImageSrc
no setter
error404 ImageSrc
no setter
info ImageSrc
no setter
nodata ImageSrc
no setter
success ImageSrc
no setter
warning ImageSrc
no setter