CustomAlert class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show({required BuildContext context, bool disableBackBtn = false, double width = 300.0, bool? resizeToAvoidBottomInset, CustomAlertImage image = const CustomAlertImage(), Text? title, double titleOffset = 10, Widget? content, double contentOffset = 10, CrossAxisAlignment alignment = CrossAxisAlignment.start, CustomAlertActions? actionWidget, MainAxisAlignment actionAlignment = MainAxisAlignment.end, bool showCancelBtn = false, String cancelBtnText = 'Cancel', String confirmBtnText = 'Ok', Color confirmBtnColor = Colors.blue, Color confirmBtnTextColor = Colors.white, double borderRadius = 12, void onCancelBtnTap()?, void onConfirmBtnTap()?, Curve curve = Curves.elasticOut, Curve reverseCurve = Curves.easeOutExpo, bool barrierDismissible = false})
→ Future<void>
-